@@ -8,13 +8,11 @@ OC.L10N.register(
     "Omit year" : "Omitir l'añu",
     "There was an error fetching the member list" : "Hebo un error al dir en cata de la llista de miembros",
     "Loading team…" : "Cargando l'equipu…",
-    "Loading contacts …" : "Cargando los contautos…",
     "There are no contacts yet" : "Nun hai nengún contautu",
     "Create contact" : "Crear un contautu",
     "There are no contacts in this group" : "Nun hai nengún contautu nesti grupu",
     "Create contacts" : "Crear contautos",
     "Add contacts" : "Amestar contautos",
-    "Loading …" : "Cargando…",
     "Leave team" : "Colar del equipu",
     "Delete team" : "Desaniciar l'equipu",
     "Contacts settings" : "Configuración de Contautos",
@@ -54,7 +52,6 @@ OC.L10N.register(
     "Phonetic last name" : "Apellíos fonéticos",
     "Display name" : "Nome visible",
     "An error happened during the config change" : "Prodúxose un error demientres el cambéu de la configuración",
-    "Unique password …" : "Contraseña única…",
     "Save" : "Guardar",
     "Failed to save password. Please try again later." : "Nun se pue guardar la contraseña. Volvi tentalo dempués.",
     "There is no description for this team" : "Nun hai nenguna descripción pa esti equipu",
@@ -93,7 +90,6 @@ OC.L10N.register(
     "Local team" : "Equipu llocal",
     "Unable to get the results" : "Nun ye posible consiguir los resultaos",
     "There was an issue adding members to the team" : "Hebo un problema al amestar los miembros al equipu",
-    "Loading members list …" : "Cargando la llista de miembros…",
     "Pending" : "Pendiente",
     "Member" : "Miembru",
     "Unable to create the contact." : "Nun ye posible crear el contautu.",
@@ -148,6 +144,10 @@ OC.L10N.register(
     "Spoken languages" : "Llingües falaes",
     "Unable to create team {circleName}" : "Nun ye posible crear l'equipu «{circleName}»",
     "Unable to delete team {circleId}" : "Nun ye posible crear l'equipu «{circled}»",
-    "Unable to delete contact" : "Nun ye posible desaniciar el contautu"
+    "Unable to delete contact" : "Nun ye posible desaniciar el contautu",
+    "Loading contacts …" : "Cargando los contautos…",
+    "Loading …" : "Cargando…",
+    "Unique password …" : "Contraseña única…",
+    "Loading members list …" : "Cargando la llista de miembros…"
 },
 "nplurals=2; plural=(n != 1);");
