@@ -4,7 +4,6 @@ OC.L10N.register(
     "Details" : "Detalles",
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
-    "Loading contacts …" : "Cargando contactos ...",
     "General settings" : "Configuraciones generales",
     "Rename" : "Renombrar",
     "Send email" : "Enviar correo electrónico",
@@ -25,7 +24,6 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Title" : "Título",
     "Groups" : "Grupos",
-    "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
     "None" : "Ninguno",
@@ -89,6 +87,8 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Loading contacts …" : "Cargando contactos ...",
+    "Search contacts …" : "Buscar contactos ..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
