@@ -11,10 +11,7 @@ OC.L10N.register(
     "Add" : "Ավելացնել",
     "First name" : "Անուն",
     "Last name" : "Ազգանուն",
-    "Password protection" : "Password protection",
     "Save" : "Պահպանել",
-    "Description" : "Նկարագրություն",
-    "Settings" : "Settings",
     "Cancel" : "ընդհատել",
     "Name" : "Անուն",
     "Title" : "Վերնագիր",
