@@ -4,6 +4,8 @@ OC.L10N.register(
     "Import contacts" : "匯入連絡人",
     "Details" : "詳細資料",
     "All contacts" : "所有聯絡人",
+    "_Imported 1 contact_::_Imported %n contacts_" : ["已匯入 %n 個聯絡人"],
+    "_Imported 1 contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已匯入 %n 個聯絡人（略過 %d 個）"],
     "Contacts" : "通訊錄",
     "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的使用者介面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們並沒有重新發明輪子！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
@@ -13,11 +15,13 @@ OC.L10N.register(
     "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
     "Please select a team" : "請選取團隊",
     "Loading team…" : "正在載入團隊……",
+    "Loading contacts …" : "正在載入聯絡人……",
     "There are no contacts yet" : "目前沒有連絡人",
     "Create contact" : "建立聯絡人",
     "There are no contacts in this group" : "群組中沒有連絡人",
     "Create contacts" : "建立聯絡人",
     "Add contacts" : "新增聯絡人",
+    "Loading …" : "正在載入……",
     "Manage team" : "管理團隊",
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
@@ -40,6 +44,7 @@ OC.L10N.register(
     "An error occurred while creating the group" : "建立群組時發生錯誤",
     "This team already exists" : "此團隊已存在",
     "An error happened during the creation of the team" : "建立團隊時發生錯誤",
+    "Recently contacted" : "最近聯絡",
     "Contact groups" : "聯絡人群組",
     "Create a new contact group" : "建立新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
@@ -89,6 +94,7 @@ OC.L10N.register(
     "An error happened during the config change" : "變更設定時發生錯誤",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
+    "Unique password …" : "獨一無二的密碼……",
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
     "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
@@ -160,6 +166,7 @@ OC.L10N.register(
     "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
     "Please select two editable contacts to merge" : "請選取兩個可編輯的聯絡人進行合併",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
+    "Search contacts …" : "搜尋聯絡人……",
     "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group}",
     "Add members to {group}" : "新增成員至 {group}",
@@ -193,11 +200,13 @@ OC.L10N.register(
     "Unable to get the results" : "無法取得結果",
     "Some members could not be added" : "無法新增部份成員",
     "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
+    "Loading members list …" : "正在載入成員清單……",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取成員清單",
     "Add to {team}" : "新增至 {team}",
     "Invite members to {team}" : "邀請成員至 {team}",
     "Pending" : "擱置中",
+    "Select chart …" : "選取圖表……",
     "Chart" : "圖表",
     "Select Date" : "選取日期",
     "Select type" : "選取類型",
@@ -235,7 +244,6 @@ OC.L10N.register(
     "Link copied to the clipboard" : "連結已複製到剪貼簿",
     "Could not copy link to the clipboard." : "無法複製連結至剪貼簿。",
     "Not grouped" : "未歸類",
-    "Recently contacted" : "最近聯絡",
     "Organization chart" : "組織圖表",
     "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "團隊是您可以自行建立並與他們分享資料的一群人。其可以由 Nextcloud 站台的其他帳號或帳號群組所組成，但也可以由您通訊錄中的聯絡人組成，甚至可以透過輸入電子郵件地址來組成外部人員。",
     "Team" : "團隊",
